/* 
  CellEditor.h

  Barry McMullin <mcmullin@eeng.dcu.ie>
  07-OCT-1996

*/

#import <objectbase/SwarmObject.h>

@interface CellEditor : SwarmObject {
  int rasterX, rasterY;
  int worldX, worldY;
  id agent;
  id agentClass;
}

-createEnd;   // Overridden...

-setRasterX: (int) newX Y: (int) newY;
-setWorldX: (int) newX Y: (int) newY;

-update;

-forceCatalyst;
-forceLink;
-forceSubstrate;
-forceHole;


@end
